==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/ArrayCore/src/ArrayCore.h <==
#ifndef ARRAYCORE_HEADERS
#define ARRAYCORE_HEADERS

// All headers of ArrayCore library

#include "AbstractArrayResults.h"
#include "AbstractArrayTool.h"
#include "AbstractFKFunction.h"
#include "ActiveConvFKRayleigh.h"
#include "ActiveConvFKVertical.h"
#include "ActiveFKParameters.h"
#include "ActiveFKSteering.h"
#include "ActiveFKSteeringOneComponent.h"
#include "ActiveFKTaskManager.h"
#include "ActiveFKTool.h"
#include "ActiveFKToolSet.h"
#include "ActiveFKWorker.h"
#include "ActiveHRFKDirectRayleigh.h"
#include "ActiveHRFKRayleigh.h"
#include "ActiveHRFKRayleighEllipticity.h"
#include "ActiveHRFKVertical.h"
#include "ArrayCoreDLLExport.h"
#include "ArrayCrossSpectrum.h"
#include "ArrayParameters.h"
#include "ArraySelection.h"
#include "ArrayStationSignals.h"
#include "ArrayStations.h"
#include "ArrayTask.h"
#include "ArrayTaskManager.h"
#include "ArrayTimeWindows.h"
#include "ArrayWorker.h"
#include "AsyncArrayProcess.h"
#include "AsyncFKLoop.h"
#include "AsyncFKTool.h"
#include "AsyncParameters.h"
#include "AsyncStationPair.h"
#include "BlockAveragingParameters.h"
#include "ConvFKRadial.h"
#include "ConvFKRayleigh.h"
#include "ConvFKTransverse.h"
#include "ConvFKVertical.h"
#include "CrossSpectrum.h"
#include "FKCache.h"
#include "FKCrossSpectrum.h"
#include "FKGradientSearch.h"
#include "FKGridSearch.h"
#include "FKParameters.h"
#include "FKPeaks.h"
#include "FKPolarGradientSearch.h"
#include "FKPower.h"
#include "FKResults.h"
#include "FKSteering.h"
#include "FKSteeringOneComponent.h"
#include "FKSteeringThreeComponentRayleighFixedEll.h"
#include "FKSteeringThreeComponentRayleighRadial.h"
#include "FKSteeringThreeComponentRayleighVertical.h"
#include "FKSteeringTwoComponentConvRayleigh.h"
#include "FKSteeringTwoComponentRadial.h"
#include "FKSteeringTwoComponentRayleighFixedEll.h"
#include "FKSteeringTwoComponentRayleighRadial.h"
#include "FKSteeringTwoComponentRayleighVertical.h"
#include "FKSteeringTwoComponentTransverse.h"
#include "FKTaskManager.h"
#include "FKTool.h"
#include "FKWorker.h"
#include "FrequencyBand.h"
#include "GaussianFrequencyBand.h"
#include "HRFKDirectLove.h"
#include "HRFKDirectRadial.h"
#include "HRFKDirectRayleigh.h"
#include "HRFKDirectRayleighFixedEll.h"
#include "HRFKDirectRayleighRadial.h"
#include "HRFKDirectRayleighRefined.h"
#include "HRFKDirectRayleighVertical.h"
#include "HRFKRadial.h"
#include "HRFKRayleigh.h"
#include "HRFKRayleighEllipticity.h"
#include "HRFKRayleighFixedEll.h"
#include "HRFKRayleighRadial.h"
#include "HRFKTransverse.h"
#include "HRFKVertical.h"
#include "KmaxSolver.h"
#include "KminSolver.h"
#include "MuttiArrayFKLoop.h"
#include "OmniFKRayleigh.h"
#include "OmniFKVertical.h"
#include "PoggiFKRadial.h"
#include "PoggiFKVertical.h"
#include "RingPairs.h"
#include "SPACCrossSpectrum.h"
#include "SPACParameters.h"
#include "SPACResults.h"
#include "SPACRing.h"
#include "SPACStatistics.h"
#include "SPACTaskManager.h"
#include "SPACTool.h"
#include "SPACWorker.h"
#include "StationPair.h"
#include "StationPairs.h"
#include "WaveNumberConverter.h"
#include "Wavenumber.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace ArrayCore;
#endif

#endif // ARRAYCORE_HEADERS

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/ArrayCore.h <==
#ifndef ARRAYCORE_HEADERS
#define ARRAYCORE_HEADERS

// All headers of ArrayCore library

#include "AbstractArrayResults.h"
#include "AbstractArrayTool.h"
#include "AbstractFKFunction.h"
#include "ActiveConvFKRayleigh.h"
#include "ActiveConvFKVertical.h"
#include "ActiveFKParameters.h"
#include "ActiveFKSteering.h"
#include "ActiveFKSteeringOneComponent.h"
#include "ActiveFKTaskManager.h"
#include "ActiveFKTool.h"
#include "ActiveFKToolSet.h"
#include "ActiveFKWorker.h"
#include "ActiveHRFKDirectRayleigh.h"
#include "ActiveHRFKRayleigh.h"
#include "ActiveHRFKRayleighEllipticity.h"
#include "ActiveHRFKVertical.h"
#include "ArrayCoreDLLExport.h"
#include "ArrayCrossSpectrum.h"
#include "ArrayParameters.h"
#include "ArraySelection.h"
#include "ArrayStationSignals.h"
#include "ArrayStations.h"
#include "ArrayTask.h"
#include "ArrayTaskManager.h"
#include "ArrayTimeWindows.h"
#include "ArrayWorker.h"
#include "AsyncArrayProcess.h"
#include "AsyncFKLoop.h"
#include "AsyncFKTool.h"
#include "AsyncParameters.h"
#include "AsyncStationPair.h"
#include "BlockAveragingParameters.h"
#include "ConvFKRadial.h"
#include "ConvFKRayleigh.h"
#include "ConvFKTransverse.h"
#include "ConvFKVertical.h"
#include "CrossSpectrum.h"
#include "FKCache.h"
#include "FKCrossSpectrum.h"
#include "FKGradientSearch.h"
#include "FKGridSearch.h"
#include "FKParameters.h"
#include "FKPeaks.h"
#include "FKPolarGradientSearch.h"
#include "FKPower.h"
#include "FKResults.h"
#include "FKSteering.h"
#include "FKSteeringOneComponent.h"
#include "FKSteeringThreeComponentRayleighFixedEll.h"
#include "FKSteeringThreeComponentRayleighRadial.h"
#include "FKSteeringThreeComponentRayleighVertical.h"
#include "FKSteeringTwoComponentConvRayleigh.h"
#include "FKSteeringTwoComponentRadial.h"
#include "FKSteeringTwoComponentRayleighFixedEll.h"
#include "FKSteeringTwoComponentRayleighRadial.h"
#include "FKSteeringTwoComponentRayleighVertical.h"
#include "FKSteeringTwoComponentTransverse.h"
#include "FKTaskManager.h"
#include "FKTool.h"
#include "FKWorker.h"
#include "HRFKDirectLove.h"
#include "HRFKDirectRadial.h"
#include "HRFKDirectRayleigh.h"
#include "HRFKDirectRayleighFixedEll.h"
#include "HRFKDirectRayleighRadial.h"
#include "HRFKDirectRayleighRefined.h"
#include "HRFKDirectRayleighVertical.h"
#include "HRFKRadial.h"
#include "HRFKRayleigh.h"
#include "HRFKRayleighEllipticity.h"
#include "HRFKRayleighFixedEll.h"
#include "HRFKRayleighRadial.h"
#include "HRFKTransverse.h"
#include "HRFKVertical.h"
#include "KmaxSolver.h"
#include "KminSolver.h"
#include "MuttiArrayFKLoop.h"
#include "OmniFKRayleigh.h"
#include "OmniFKVertical.h"
#include "PoggiFKRadial.h"
#include "PoggiFKVertical.h"
#include "RingPairs.h"
#include "SPACCrossSpectrum.h"
#include "SPACParameters.h"
#include "SPACPeaks.h"
#include "SPACResults.h"
#include "SPACRing.h"
#include "SPACStatistics.h"
#include "SPACTaskManager.h"
#include "SPACTool.h"
#include "SPACWorker.h"
#include "SingleDirectRayleigh.h"
#include "StationPair.h"
#include "StationPairs.h"
#include "WaveNumberConverter.h"
#include "Wavenumber.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace ArrayCore;
#endif

#endif // ARRAYCORE_HEADERS
